@@ -3,3 +3,7 @@ from pybotx.client.exceptions.base import BaseClientError
 
 class UserNotFoundError(BaseClientError):
     """User not found."""
+
+
+class InvalidProfileDataError(BaseClientError):
+    """Invalid profile data."""
